@@ -13,52 +13,60 @@ from .storage import get_metadata
 
 
 AuthTable = sa.Table(
-    'auth',
+    "auth",
     get_metadata(),
-    sa.Column('pubkey', sa.Text(), primary_key=True),
-    sa.Column('roles', sa.Text()),
-    sa.Column('created', sa.DateTime())
+    sa.Column("pubkey", sa.Text(), primary_key=True),
+    sa.Column("roles", sa.Text()),
+    sa.Column("created", sa.DateTime()),
 )
 
 
 class Role(enum.Enum):
-    anonymous = 'a'
-    reader = 'r'
-    writer = 'w'
-    admin = 's'
+    anonymous = "a"
+    reader = "r"
+    writer = "w"
+    admin = "s"
 
 
 class Action(enum.Enum):
-    query = 'query'
-    save = 'save'
-    read_dm = 'read_dm'
-
+    query = "query"
+    save = "save"
+    read_dm = "read_dm"
 
 
 class Authenticator:
     """
     Authenticate, according to NIP-42
     """
+
     def __init__(self, storage, options):
         self.default_roles = set(Role.anonymous.value)
         self.storage = storage
-        self.actions, self.valid_urls, self.is_enabled, self.throttle_unauthenticated = self.parse_options(options)
-        self.log = logging.getLogger('nostr_relay.auth')
+        (
+            self.actions,
+            self.valid_urls,
+            self.is_enabled,
+            self.throttle_roles,
+        ) = self.parse_options(options)
+        self.log = logging.getLogger("nostr_relay.auth")
         if self.is_enabled:
             self.log.info("Authentication enabled for %s", self.valid_urls)
 
     def parse_options(self, options):
-        actions = {Action.save.value: self.default_roles, Action.query.value: self.default_roles}
-        valid_urls = options.get('relay_urls', 'ws://localhost:6969')
-        for action, roles in options.get('actions', {}).items():
+        actions = {
+            Action.save.value: self.default_roles,
+            Action.query.value: self.default_roles,
+        }
+        valid_urls = options.get("relay_urls", "ws://localhost:6969")
+        for action, roles in options.get("actions", {}).items():
             if isinstance(action, Action):
                 action = action.value
             if isinstance(roles, Role):
                 roles = roles.value
             actions[action] = set(roles)
-        enabled = options.get('enabled', False)
-        throttle_unauthenticated = float(options.get('throttle_unauthenticated', 0.0))
-        return actions, valid_urls, enabled, throttle_unauthenticated
+        throttle_roles = options.get("throttle", {})
+        enabled = options.get("enabled", False)
+        return actions, valid_urls, enabled, throttle_roles
 
     def get_challenge(self, remote_addr):
         """
@@ -82,11 +90,11 @@ class Authenticator:
             raise AuthenticationError("invalid: Too new")
         found_relay = found_challenge = False
         for tag in auth_event.tags:
-            if tag[0] == 'relay':
+            if tag[0] == "relay":
                 if tag[1] not in self.valid_urls:
-                    raise AuthenticationError("invalid: Wrong domain")
+                    raise AuthenticationError(f"invalid: Wrong domain: {tag[1]}")
                 found_relay = True
-            elif tag[0] == 'challenge':
+            elif tag[0] == "challenge":
                 if tag[1] != challenge:
                     raise AuthenticationError("invalid: Wrong challenge")
                 found_challenge = True
@@ -95,10 +103,10 @@ class Authenticator:
 
     async def evaluate_target(self, auth_token, action, target):
         if action == Action.read_dm.value:
-            if auth_token.get('pubkey') != target.pubkey:
+            if auth_token.get("pubkey") != target.pubkey:
                 return False
         elif action == Action.save.value:
-            if auth_token.get('pubkey') == target.pubkey:
+            if auth_token.get("pubkey") == target.pubkey:
                 return True
         # TODO: implement per-object permissions here
         return True
@@ -108,7 +116,9 @@ class Authenticator:
         Get the roles assigned to the public key
         """
         async with self.storage.db.begin() as conn:
-            result = await conn.execute(sa.select(AuthTable.c.roles).where(AuthTable.c.pubkey == pubkey))
+            result = await conn.execute(
+                sa.select(AuthTable.c.roles).where(AuthTable.c.pubkey == pubkey)
+            )
             row = result.fetchone()
         if row:
             return set(row[0].lower())
@@ -122,7 +132,7 @@ class Authenticator:
         async with self.storage.db.begin() as conn:
             result = await conn.stream(sa.select(AuthTable.c.pubkey, AuthTable.c.roles))
             async for pubkey, role in result:
-                yield pubkey, set((role or '').lower())
+                yield pubkey, set((role or "").lower())
 
     async def set_roles(self, pubkey: str, roles: str):
         """
@@ -130,11 +140,19 @@ class Authenticator:
         """
         async with self.storage.db.begin() as conn:
             try:
-                await conn.execute(sa.insert(AuthTable).values(pubkey=pubkey, roles=roles, created=datetime.now()))
+                await conn.execute(
+                    sa.insert(AuthTable).values(
+                        pubkey=pubkey, roles=roles, created=datetime.now()
+                    )
+                )
             except sa.exc.IntegrityError:
-                await conn.execute(sa.update(AuthTable).where(AuthTable.c.pubkey == pubkey).values(roles=roles))
+                await conn.execute(
+                    sa.update(AuthTable)
+                    .where(AuthTable.c.pubkey == pubkey)
+                    .values(roles=roles)
+                )
 
-    async def authenticate(self, auth_event_json: dict, challenge: str=''):
+    async def authenticate(self, auth_event_json: dict, challenge: str = ""):
         """
         Authenticate, using the authentication event described in NIP-42
 
@@ -144,11 +162,11 @@ class Authenticator:
         self.check_auth_event(auth_event, challenge)
 
         token = {
-            'pubkey': auth_event.pubkey,
-            'roles': await self.get_roles(auth_event.pubkey),
-            'now': time(),
+            "pubkey": auth_event.pubkey,
+            "roles": await self.get_roles(auth_event.pubkey),
+            "now": time(),
         }
-        self.log.info("Authenticated %s. roles:%s", auth_event.pubkey, token['roles'])
+        self.log.info("Authenticated %s. roles:%s", auth_event.pubkey, token["roles"])
         return token
 
     async def can_do(self, auth_token: dict, action: str, target=None):
@@ -161,17 +179,34 @@ class Authenticator:
         can_do = True
         if self.is_enabled:
             if action in self.actions:
-                can_do = bool(self.actions[action].intersection(auth_token.get('roles', self.default_roles)))
+                can_do = bool(
+                    self.actions[action].intersection(
+                        auth_token.get("roles", self.default_roles)
+                    )
+                )
                 if can_do and target:
                     can_do = await self.evaluate_target(auth_token, action, target)
         return can_do
 
+    async def should_throttle(self, auth_token: dict):
+        """
+        Return whether the client should be throttled, based on the configuration in `throttle`
+        """
+        if not auth_token:
+            throttle_amount = self.throttle_roles.get("unauthenticated", 0)
+        else:
+            throttle_amount = max(
+                self.throttle_roles.get(role, 0) for role in auth_token.get("roles", [])
+            )
+        return throttle_amount
+
 
 def get_authenticator(storage, configuration: dict):
     """
     Return an authenticator object, according to the configuration dict
     """
 
-    classpath = configuration.get('authenticator_class', 'nostr_relay.auth.Authenticator')
+    classpath = configuration.get(
+        "authenticator_class", "nostr_relay.auth.Authenticator"
+    )
     return call_from_path(classpath, storage, configuration)
-
